@@ -1889,7 +1889,7 @@ gsd_wacom_device_get_area (GsdWacomDevice *device)
 				 XA_INTEGER, &realtype, &realformat, &nitems,
 				 &bytes_after, &data);
 	if (gdk_error_trap_pop () || rc != Success || realtype == None || bytes_after != 0 || nitems != 4) {
-		xdevice_close (xdevice);
+		XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdevice);
 		return NULL;
 	}
 
@@ -1898,7 +1898,7 @@ gsd_wacom_device_get_area (GsdWacomDevice *device)
 		device_area[i] = ((long *)data)[i];
 
 	XFree (data);
-	xdevice_close (xdevice);
+	XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdevice);
 
 	return device_area;
 }
